.. _glossary:


********
Glossary
********

.. if you add new entries, keep the alphabetical sorting!

.. glossary::

   aiohttp

      :term:`asyncio` compatible library for working with HTTP protocol.

   asyncio

      Reference implementation of :pep:`3156` --- Asynchronous IO
      Support Rebooted.

   ElasticSearch

      A search server based on Lucene. It provides a distributed,
      multitenant-capable full-text search engine with a RESTful web
      interface and schema-free JSON documents.

      http://www.elasticsearch.org

   elasticsearch-py

      Official python client for :term:`ElasticSearch`

   ipdb

      ipdb exports functions to access the IPython debugger, which
      features tab completion, syntax highlighting, better tracebacks,
      better introspection with the same interface as the pdb module.

   pep8

      Python style guide checker

      *pep8* is a tool to check your Python code against some of the
      style conventions in :pep:`8` -- Style Guide for Python Code.

   pyflakes

      passive checker of Python programs

      A simple program which checks Python source files for errors.

      Pyflakes analyzes programs and detects various errors. It works
      by parsing the source file, not importing it, so it is safe to
      use on modules with side effects. It's also much faster.

      https://pypi.python.org/pypi/pyflakes

   venv

      standard python module for creating lightweight “virtual
      environments” with their own site directories, optionally
      isolated from system site directories. Each virtual environment
      has its own Python binary (allowing creation of environments
      with various Python versions) and can have its own independent
      set of installed Python packages in its site directories.

      https://docs.python.org/dev/library/venv.html

   virtualenv

      The tool to create isolated Python environments. It's not
      included into python stdlib's but it is very popular instrument.

      :term:`venv` and :term:`virtualenv` does almost the same, *venv*
      has been developed after the *virtualenv*.

      http://virtualenv.readthedocs.org/en/latest/

   virtualenvwrapper

      virtualenvwrapper is a set of extensions to Ian Bicking’s
      :term:`virtualenv` tool. The extensions include wrappers for
      creating and deleting virtual environments and otherwise
      managing your development workflow, making it easier to work on
      more than one project at a time without introducing conflicts in
      their dependencies.

      virtualenvwrapper is my choice, highly recommend the tool to everyone.

      http://virtualenvwrapper.readthedocs.org/en/latest/
